pkglts\.option\.pypi package
============================

Submodules
----------

pkglts\.option\.pypi\.config module
-----------------------------------

.. automodule:: pkglts.option.pypi.config
    :members:
    :undoc-members:
    :show-inheritance:

pkglts\.option\.pypi\.handlers module
-------------------------------------

.. automodule:: pkglts.option.pypi.handlers
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: pkglts.option.pypi
    :members:
    :undoc-members:
    :show-inheritance:
